package edu.lawrence.graphpad

import androidx.room.Dao
import androidx.room.Database
import androidx.room.Insert
import androidx.room.Query
import androidx.room.RoomDatabase
import androidx.room.Update

@Dao
interface GraphDao {
    @Insert
    suspend fun addGraph(graph : GraphInfo)

    @Insert
    suspend fun addVertex(vertex : Vertex) : Long

    @Insert
    suspend fun addEdge(edge : EdgeInfo)

    @Update
    suspend fun updateVertex(vertex : Vertex)

    @Query("select * from graphs")
    suspend fun loadGraphs() : List<GraphInfo>

    @Query("select * from vertices where graph = :graph")
    suspend fun loadVertices(graph:Int) : List<Vertex>

    @Query("select * from vertices where id = :id")
    suspend fun findVertex(id:Int) : Vertex

    @Query("select * from edges where graph = :graph")
    suspend fun loadEdges(graph:Int) : List<EdgeInfo>
}

@Database(entities = [Vertex::class,EdgeInfo::class,GraphInfo::class], version = 1)
abstract class GraphDatabase : RoomDatabase() {
    abstract fun graphDao() : GraphDao
}