package edu.lawrence.graphpad

import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.drawscope.DrawScope
import androidx.room.Entity
import androidx.room.PrimaryKey

const val radius = 20.0f

@Entity(tableName = "vertices")
class Vertex(@PrimaryKey(autoGenerate=true) val id : Int = 0,var centerX : Float, var centerY : Float, var graph : Int) {

    fun drawIn(scope: DrawScope) {
        scope.drawCircle(color = Color.Red, radius = radius,
            center = Offset(x = centerX , y = centerY))
    }

    fun containsPoint(pt : Offset) : Boolean {
        val deltaX = (centerX - pt.x)
        val deltaY = (centerY - pt.y)
        val r = 1.5*radius
        val distSquared = deltaX*deltaX + deltaY*deltaY
        return distSquared < r*r
    }
}

@Entity(tableName = "edges")
class EdgeInfo(@PrimaryKey(autoGenerate=true) val id : Int = 0,var origin : Int,var dest : Int,var graph : Int)

class Edge(var origin : Vertex,var dest: Vertex){
    fun drawIn(scope: DrawScope) {
        scope.drawLine(
            color = Color.Green,
            start = Offset(x = origin.centerX, y = origin.centerY),
            end = Offset(x = dest.centerX, y = dest.centerY),
            strokeWidth = 3.0f
        )
    }
}

@Entity(tableName = "graphs")
class GraphInfo(@PrimaryKey(autoGenerate=true) val id : Int = 0,var name : String)